/** @jsx jsx */
import { useRef, useState } from 'react';

// eslint-disable-next-line @atlaskit/ui-styling-standard/use-compiled -- Ignored via go/DSP-18766
import { css, jsx } from '@emotion/react';
import { injectIntl } from 'react-intl-next';
import { useSharedPluginState } from '@atlaskit/editor-common/hooks';
import { highlightMessages as messages } from '@atlaskit/editor-common/messages';
import { TOOLBAR_BUTTON, ToolbarButton } from '@atlaskit/editor-common/ui-menu';
import { hexToEditorTextBackgroundPaletteColor } from '@atlaskit/editor-palette';
import ExpandIcon from '@atlaskit/icon/glyph/chevron-down';
import { EditorHighlightIcon } from './shared/EditorHighlightIcon';
import { PaletteDropdown } from './shared/PaletteDropdown';
import { useDropdownEvents } from './shared/useDropdownEvents';
const expandIconContainerStyle = css({
  margin: `0px ${"var(--ds-space-negative-050, -4px)"}`
});
const highlightIconContainerStyle = css({
  marginTop: "var(--ds-space-negative-050, -4px)"
});
const FloatingToolbarHighlightColor = ({
  pluginInjectionApi,
  intl: {
    formatMessage
  }
}) => {
  const toolbarItemRef = useRef(null);
  const {
    highlightState
  } = useSharedPluginState(pluginInjectionApi, ['highlight']);
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);
  const {
    handleClick,
    handleKeyDown,
    handleClickOutside,
    handleEscapeKeydown,
    handleColorChange,
    isOpenedByKeyboard
  } = useDropdownEvents({
    toolbarItemRef,
    setIsDropdownOpen,
    isDropdownOpen,
    pluginInjectionApi
  });

  // Don't render the toolbar option while the plugin is initialising
  if (!highlightState) {
    return null;
  }
  const toolbarButtonLabel = formatMessage(messages.highlight);

  // Get the design token for the  active color (if it exists) to modify the toolbar
  // icon, but show the nice rainbow if none is selected
  const activeColorToken = highlightState.activeColor === null ? null : hexToEditorTextBackgroundPaletteColor(highlightState.activeColor);
  return jsx(PaletteDropdown, {
    isOpen: isDropdownOpen && !highlightState.disabled,
    activeColor: highlightState.activeColor,
    trigger: jsx(ToolbarButton, {
      buttonId: TOOLBAR_BUTTON.BACKGROUND_COLOR,
      spacing: 'compact',
      disabled: highlightState.disabled,
      selected: isDropdownOpen,
      "aria-label": toolbarButtonLabel,
      "aria-expanded": isDropdownOpen,
      "aria-haspopup": true,
      title: toolbarButtonLabel,
      onClick: handleClick,
      onKeyDown: handleKeyDown,
      ref: toolbarItemRef,
      iconBefore: jsx("span", {
        css: highlightIconContainerStyle
      }, jsx(EditorHighlightIcon, {
        selectedColor: activeColorToken,
        disabled: highlightState.disabled
      })),
      iconAfter: jsx("span", {
        css: expandIconContainerStyle
      }, jsx(ExpandIcon, {
        label: ""
      }))
    }, formatMessage(messages.highlightFloatingToolbar)),
    onColorChange: color => handleColorChange(color),
    isOpenedByKeyboard: isOpenedByKeyboard,
    handleClickOutside: handleClickOutside,
    handleEscapeKeydown: handleEscapeKeydown
  });
};
export const FloatingToolbarHighlightColorWithIntl = injectIntl(FloatingToolbarHighlightColor);